<?php

declare(strict_types=1);

namespace Drupal\yufu_concept;

use Psr\Http\Client\ClientInterface;
use Drupal\Core\Site\Settings;
use GuzzleHttp\Psr7\Response;

/**
 * Ta service omogoča prevajanje preko libretranslate APIja.
 * @TODO to bi bilo mogoče izfaktorirat in spolirat v svoj, ločen modul.
 */
final class Translate {
  private $baseUrl;
  private $apiKey;

  /**
   * Constructs a Translate object.
   */
  public function __construct(
    private readonly ClientInterface $httpClient,
    private readonly Settings $settings
  ) {
    $this->baseUrl = $settings->get('yufu_libretranslate_url', FALSE);
    $this->apiKey = $settings->get('yufu_libretranslate_apikey', FALSE);
  }

  /**
    * Prevede $besedila iz $izvorniJezik v $ciljniJezik
    */
  public function prevedi(array $besedila, $izvorniJezik, $ciljniJezik): ?array {
    $odziv = $this->request('translate', [
      'json' => [
        'q' => $besedila,
        'source' => $izvorniJezik,
        'target' => $ciljniJezik,
        'format' => 'text'
      ]
    ]);

    if ($odziv->getStatusCode() == 200) {
      $json = json_decode($odziv->getBody()->getContents(), true);
      return $json['translatedText'];
    }

    return null;
  }

  /**
   * Poizvedi na libretranslate API. Doda apiKey.
   */
  public function request($url, $opts = []): ?Response {
    $uri = "{$this->baseUrl}/$url";
    if (!isset($opts['json'])) {
      $opts['json'] = [];
    }
    $opts['json']['api_key'] = $this->apiKey;

    return $this->httpClient->post($uri, $opts);
  }

}
